@@ -1,8 +1,9 @@
 /* vi: ts=8 sts=4 sw=4
  *
  * This file is part of the KDE project, module kdesu.
- * Copyright (C) 1998 Pietro Iglio <iglio@fub.it>
- * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
+ * SPDX-FileCopyrightText: 1998 Pietro Iglio <iglio@fub.it>
+ * SPDX-FileCopyrightText: 1999, 2000 Geert Jansen <jansen@kde.org>
+ * SPDX-License-Identifier: Artistic-2.0
  */
 
 #include <config-kde-cli-tools.h>
@@ -266,7 +267,8 @@ static int startApp(QCommandLineParser &p)
             p.showHelp(1);
         }
     }
-    foreach (const QString &arg, p.positionalArguments()) {
+    const auto positionalArguments = p.positionalArguments();
+    for (const QString &arg : positionalArguments) {
         command += ' ';
         command += QFile::encodeName(KShell::quoteArg(arg));
     }
@@ -376,7 +378,8 @@ static int startApp(QCommandLineParser &p)
         qDebug() << "Don't need password!!\n";
     }
 
-    for (const QChar character : QString::fromLocal8Bit(command)) {
+    const QString cmd = QString::fromLocal8Bit(command);
+    for (const QChar character : cmd) {
         if (!character.isPrint() && character.category() != QChar::Other_Surrogate) {
             return -2;
         }
